@@ -3,12 +3,12 @@ package Acme::CPANModules::PortedFrom::Python;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-04-23'; # DATE
+our $DATE = '2023-10-31'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-Python'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $LIST = {
-    summary => "Modules/applications that are ported from (or inspired by) ".
+    summary => "List of modules/applications that are ported from (or inspired by) ".
         "Python libraries",
     description => <<'_',
 
@@ -66,7 +66,7 @@ _
 };
 
 1;
-# ABSTRACT: Modules/applications that are ported from (or inspired by) Python libraries
+# ABSTRACT: List of modules/applications that are ported from (or inspired by) Python libraries
 
 __END__
 
@@ -76,11 +76,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::PortedFrom::Python - Modules/applications that are ported from (or inspired by) Python libraries
+Acme::CPANModules::PortedFrom::Python - List of modules/applications that are ported from (or inspired by) Python libraries
 
 =head1 VERSION
 
-This document describes version 0.007 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2023-04-23.
+This document describes version 0.008 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2023-10-31.
 
 =head1 DESCRIPTION
 
